aboutsummaryrefslogtreecommitdiff
path: root/lib/joinstate.h
diff options
context:
space:
mode:
authorAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
committerAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
commit09eb39236666e81d5da014acea011dcd74d0999b (patch)
tree52876d96be71be1a39d5d935c1295a51995e8949 /lib/joinstate.h
parentf1788ee27f33e9339334e0d79bde9a27d9ce2e44 (diff)
parenta4e78956f105875625b572d8b98459ffa86fafe5 (diff)
downloadlibquotient-09eb39236666e81d5da014acea011dcd74d0999b.tar.gz
libquotient-09eb39236666e81d5da014acea011dcd74d0999b.zip
Update upstream source from tag 'upstream/0.6.4'
Update to upstream version '0.6.4' with Debian dir aa8705fd74743e79c043bc9e3e425d5064404cfe
Diffstat (limited to 'lib/joinstate.h')
-rw-r--r--lib/joinstate.h43
1 files changed, 21 insertions, 22 deletions
diff --git a/lib/joinstate.h b/lib/joinstate.h
index 379183f6..31c2b6a7 100644
--- a/lib/joinstate.h
+++ b/lib/joinstate.h
@@ -13,7 +13,7 @@
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
#pragma once
@@ -22,27 +22,26 @@
#include <array>
-namespace QMatrixClient
-{
- enum class JoinState : unsigned int
- {
- Join = 0x1,
- Invite = 0x2,
- Leave = 0x4,
- };
+namespace Quotient {
+enum class JoinState : unsigned int {
+ Join = 0x1,
+ Invite = 0x2,
+ Leave = 0x4,
+};
- Q_DECLARE_FLAGS(JoinStates, JoinState)
+Q_DECLARE_FLAGS(JoinStates, JoinState)
- // We cannot use REGISTER_ENUM outside of a Q_OBJECT and besides, we want
- // to use strings that match respective JSON keys.
- static const std::array<const char*, 3> JoinStateStrings
- { { "join", "invite", "leave" } };
+// We cannot use Q_ENUM outside of a Q_OBJECT and besides, we want
+// to use strings that match respective JSON keys.
+static const std::array<const char*, 3> JoinStateStrings { { "join", "invite",
+ "leave" } };
- inline const char* toCString(JoinState js)
- {
- size_t state = size_t(js), index = 0;
- while (state >>= 1) ++index;
- return JoinStateStrings[index];
- }
-} // namespace QMatrixClient
-Q_DECLARE_OPERATORS_FOR_FLAGS(QMatrixClient::JoinStates)
+inline const char* toCString(JoinState js)
+{
+ size_t state = size_t(js), index = 0;
+ while (state >>= 1u)
+ ++index;
+ return JoinStateStrings[index];
+}
+} // namespace Quotient
+Q_DECLARE_OPERATORS_FOR_FLAGS(Quotient::JoinStates)